#! /bin/csh
#-------------------------------------------------------------------------------
#
#     Name:   
#        af2_configure
#
#     Invocation:
#        af2_configure
#
#     Description:
#        C-shell script for running af2_configure.  Sets up the path to
#        the standard reference files and runs af2_configure.
#
#     Arguments:
#        None
#
#     Language:
#        C-shell
#
#     Non-standard language extensions:
#        None
#
#     Algorithm:
#        -- Search for and run the af2 startup script.
#        -- Run the af2_configure binary.
#
#     Authors:
#        (JRL): James R. Lewis -- RGO, Cambridge
#
#     History:
#        01 Dec 1995 (JRL):
#           Original version
#        03 Sep 1996 (JRL):
#           Incorporated af2_cscan
#
#-------------------------------------------------------------------------------

#  Source the startup script.

source `dirname $0`"/af2_start"
if ($af2_status != 0) goto exit

#  Get the latest AF2 fibre and telescope .dat files

echo -n "Get the latest AF2 fibre and telescope .dat files (no) > "
set ans = $<
if ($ans == "") then
   set ans = "n"
else if ($ans != "\!\!") then
   set ans = `echo $ans | tr "[A-Z]" "[a-z]" | awk '{print(substr($0,1,1))}'`
endif
if ($ans == "y") then
   wget -N -P `dirname $0` http://www.ing.iac.es/Astronomy/instruments/af2/small_fibres.dat
   wget -N -P `dirname $0` http://www.ing.iac.es/Astronomy/instruments/af2/large_fibres.dat
   wget -N -P `dirname $0` http://www.ing.iac.es/Astronomy/instruments/af2/wht_prime.dat
endif

#  See if you want to determine the best position angle by scanning.

echo -n "Do initial placement by scanning SKYPA? (no) > "
set ans = $<
if ($ans == "") then
   set ans = "n"
else if ($ans != "\!\!") then
   set ans = `echo $ans | tr "[A-Z]" "[a-z]" | awk '{print(substr($0,1,1))}'`
endif

#  Run the configure executable...
set af2confcmd = `dirname $0`"/af2_configure.x"
set af2cscancmd = `dirname $0`"/af2_cscan.x"

#  Check whether platform specific executables exist
if (-e `dirname $0`"/af2_configure.x."`uname -s`"."`uname -m`) then
   set af2confcmd = `dirname $0`"/af2_configure.x."`uname -s`"."`uname -m`
endif
if (-e `dirname $0`"/af2_cscan.x."`uname -s`"."`uname -m`) then
   set af2cscancmd = `dirname $0`"/af2_cscan.x."`uname -s`"."`uname -m`
endif

echo "Using excecutable $af2confcmd ..."


if ($ans == "n") then
   $af2confcmd
else if ($ans == "y") then
   $af2cscancmd
else if ($ans == "\!\!") then
   echo '***Abort requested***'
else
   echo '***Illegal response -- "yes" or "no", please***'
endif

exit:
