#include <stdio.h>
#include <stdlib.h>
#include "af2_par.h"

#ifdef REMOVE_CSUB_UNDERSCORE
int csub_typesize_(type,status)
#else
int csub_typesize__(type,status)
#endif
/*----------------------------------------------------------------------------*/
/*                                                                            */
/*    Name:                                                                   */
/*       csub_typesize_                                                       */
/*                                                                            */
/*    Invocation:                                                             */
/*       call csub_typesize(type,status)                                      */
/*                                                                            */
/*    Description:                                                            */
/*       Return the number of bytes per datum given a data type code.  This   */
/*       is meant to be called from a FORTRAN routine.                        */
/*                                                                            */
/*    Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)         */
/*       type: Int* (>)                                                       */
/*          The data type code                                                */
/*       status:  Int* (!)                                                    */
/*          The global status variable                                        */
/*                                                                            */
/*    Returns:                                                                */
/*       size:  Int                                                           */
/*          The number of bytes for the given data type code                  */
/*                                                                            */
/*    Language:                                                               */
/*       ANSI C                                                               */
/*                                                                            */
/*    Non-standard language extensions:                                       */
/*       None                                                                 */
/*                                                                            */
/*    Algorithm:                                                              */
/*       -- Search through the list of available types in af2_par.h and       */
/*          get the appropriate data size using the intrinsic sizeof          */
/*          function.                                                         */
/*                                                                            */
/*    Authors:                                                                */
/*       (JRL): James R. Lewis -- RGO, Cambridge                              */
/*                                                                            */
/*    History:                                                                */
/*       01 Dec 1995 (JRL):                                                   */
/*          Original version                                                  */
/*                                                                            */
/*----------------------------------------------------------------------------*/

/* Parameters */
int *const type;
int *const status;

{

      /* Local variables */
      int size;

      /* Inherited status */
      if (*status != AF2_OK) return ;

      /* Now search for appropriate data type */
      if (*type == TY_INT)
         size = sizeof(int);
      else if (*type == TY_FLOAT)
         size = sizeof(float);
      else if (*type == TY_DOUBLE)
         size = sizeof(double);
      else if (*type == TY_CHAR)
         size = sizeof(char);
      else {
         fprintf(stderr,"Illegal data type -- programming error");
         *status = AF2_ERR;
      }

      /* Return the correct size */
      return(size);
}
