      subroutine rd2rad(irah,iram,ras,idd,idm,ds,test,ra,dec)
C+------------------------------------------------------------------------------
C
C     Name:   
C        rd2rad
C
C     Invocation:
C        call rd2rad(irah,iram,ras,idd,idm,ds,test,ra,dec)
C
C     Description:
C        Convert ra and dec to radians.
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        irah:  Integer (>)
C           Number of hours in RA
C        iram:  Integer (>)
C           Number of minutes in RA
C        ras:  Real (>)
C           Number of seconds in RA
C        idd:  Integer (>)
C           Number of degrees in DEC
C        idm:  Integer (>)
C           Number of minutes in DEC
C        ds:  Real (>)
C           Number of seconds in DEC
C        test:  Character (>)
C           String with whole declination as it was read from input file
C        ra:  Double precision (<)
C           Output RA in radians
C        dec:  Double precision (<)
C           Output DEC in radians
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, variable names > 6 characters
C
C     Logical i/o units used:
C        none
C
C     External routines called:
C        Library slalib:
C           sla_daf2r
C           sla_dtf2r
C 
C     Algorithm:
C        -- Convert RA from hours to radians, convert DEC from degrees to 
C           radians using double precision slalib routines.
C        -- Search the test character string (which should contain the 
C           whole declination as it was read from the input file before it 
C           was broken down into individual fields) for a '-' sign. If 
C           one is found then make the declination negative.
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Parameters
C
      integer irah
      integer iram
      real ras
      integer idd
      integer idm
      real ds
      character test*(*)
      double precision ra
      double precision dec
C
C     Local variables
C
      integer istat
C
C     Convert RA and DEC to radians
C
      call sla_dtf2r(irah,iram,dble(ras),ra,istat)
      call sla_daf2r(abs(idd),abs(idm),abs(dble(ds)),dec,istat)
C
C     Look for the minus sign in the declination
C
      if (index(test,'-') .ne. 0) dec = -dec
      end

      subroutine rad2rd(ra,dec,irah,iram,ras,idd,idm,ds,decsign)
C+------------------------------------------------------------------------------
C
C     Name:   
C        rad2rd
C
C     Invocation:
C        call rad2rd(ra,dec,irah,iram,ras,idd,idm,ds,decsign)
C
C     Description:
C        Convert ra and dec to radians.
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        ra:  Double precision (>)
C           Input RA in radians
C        dec:  Double precision (>)
C           Input DEC in radians
C        irah:  Integer (<)
C           Number of hours in RA
C        iram:  Integer (<)
C           Number of minutes in RA
C        ras:  Real (<)
C           Number of seconds in RA
C        idd:  Integer (<)
C           Number of degrees in DEC
C        idm:  Integer (<)
C           Number of minutes in DEC
C        ds:  Real (<)
C           Number of seconds in DEC
C        decsign:  Character (<)
C           String with either '+' or '-' depending upon the sign of the dec
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, variable names > 6 characters
C
C     Logical i/o units used:
C        none
C
C     External routines called:
C        Library slalib:
C           sla_dr2af
C           sla_dr2tf
C 
C     Algorithm:
C        -- Convert RA from radians to hours, convert DEC from radians to
C           degrees using double precision slalib routines.  Do both to
C           three decimal places in the seconds field.
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Parameters
C
      double precision ra
      double precision dec
      integer irah
      integer iram
      real ras
      integer idd
      integer idm
      real ds
      character decsign*(*)
C
C     Local variables
C
      integer iwork(4)
C
C     First convert the RA
C
      call sla_dr2tf(3,ra,decsign,iwork)
      irah = iwork(1)
      iram = iwork(2)
      ras = real(iwork(3)) + 0.001*real(iwork(4))
C
C     Now convert the declination
C
      call sla_dr2af(3,dec,decsign,iwork)
      idd = iwork(1)
      idm = iwork(2)
      ds = real(iwork(3)) + 0.001*real(iwork(4))
C
C     Exit
C
      end
