      subroutine setup_plot(piv_r,field_size,pgrad,init,hard,pscale,
     :   label,status)
C+------------------------------------------------------------------------------
C
C     Name:   
C        setup_plot
C
C     Invocation:
C        call setup_plot(piv_r,field_size,pgrad,init,hard,pscale,
C           label,status)
C
C     Description:
C        Set up the viewport and window for a plot.  Include the message
C        and options windows if desired.  Draw and label the axes and
C        mark the pivot and park circles.
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        piv_r:  Real (>)
C           The radius of the pivot circle
C        field_size:  Real (>)
C           The radius of the accessable field
C        pgrad:  Real (>)
C           The maximum radius of the field to be displayed
C        init:  Logical (>)
C           TRUE if you are initialising the plot
C        hard:  Logical (>)
C           TRUE if this is supposed to be a hard copy
C        pscale:  Real array (>)
C           Plot scaling factors: 1 -- the linear scale, 2 -- the text height
C        label:  Character (>)
C           A character string specifying a field name label
C        status:  Integer (!)
C           The global status variable
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, variable names > 6 characters
C
C     Logical i/o units used:
C        none
C
C     External routines called:
C        Library chr:
C           chr_len
C
C        Library pgplot:
C           pgbox
C           pgcirc
C           pglabel
C           pgmtext
C           pgqvp
C           pgqwin
C           pgrect
C           pgsch
C           pgsfs
C           pgtext
C           pgvport
C           pgvstand
C           pgwindow
C           pgwnad
C 
C     Algorithm:
C        -- If this is not a hard copy, the draw up the options window 
C           and the message window.  Initialise the location for the first
C           message.
C        -- Draw the axes and labels for the fibre plot and draw circles
C           denoting the pivot and park radii.
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Global parameters
C
      include 'AF2_PAR.INC'
C
C     Parameters
C
      integer piv_r
      real field_size
      real pgrad
      logical init
      logical hard
      real pscale(2)
      character label*(*)
      integer status 
C
C     Local variables
C
      real plotlim(4),vlim(4),ymsg,space
C
C     Functions
C
      integer chr_len
C
C     Common blocks
C
      common /msgloc/ ymsg,space
C
C     Inherited status
C
      if (status .ne. af2_ok) go to 500
C
C     Set the character height
C 
      call pgsch(pscale(2))
C
C     If this is not a hard copy, then set up the information and message 
C     panels on the lhs of the viewport
C
      if (.not. hard) then
C 
C        If we're going to plot commands key, we need to remember the window
C        settings set by the calling routine. 
C 
         if (.not. init ) then
            call pgqwin(plotlim(1),plotlim(2),plotlim(3),plotlim(4))
            call pgqvp(0,vlim(1),vlim(2),vlim(3),vlim(4))
         end if
C 
C        Draw the window for the commands key
C
         call pgvport(0.0,0.35*pscale(1),0.0,1.0)
         call pgwindow(0.0,1.0,0.0,1.0)
         call pgsfs(2)
         call pgrect(0.04,0.95,0.50,0.99)
C
C        Now list the available options 
C
         call pgtext(0.3,0.950,'OPTIONS')
         call pgtext(0.1,0.925,'# - Same as F, but type number')
         call pgtext(0.1,0.900,'A - Undo last undo')
         call pgtext(0.1,0.875,'C - Move fibre to cursor location')
         call pgtext(0.1,0.850,'E - End')
         call pgtext(0.1,0.825,'F - Get info on fibre')
         call pgtext(0.1,0.800,'H - Make hardcopy plot')
         call pgtext(0.1,0.775,'I - Get info on object')
         call pgtext(0.1,0.750,'M - Move fibre to object')
         call pgtext(0.1,0.725,'O - Zoom out')
         call pgtext(0.1,0.700,'P - Park fibre')
         call pgtext(0.1,0.675,'R - Refresh plot')
         call pgtext(0.1,0.650,'S - Status of current placement')
         call pgtext(0.1,0.625,'U - Undo last action')
         call pgtext(0.1,0.600,'X - Maximise plot')
         call pgtext(0.1,0.575,'Y - Restart editing session')
         call pgtext(0.1,0.550,'Z - Zoom in')
C
C        Draw the window for the message box
C
         call pgrect(0.04,0.95,0.02,0.47)
         call pgtext(0.3,0.44,'MESSAGES')
         ymsg = 1.0 - space
      end if
C
C     If this is the first time for this plot, then set the viewport for
C     the main area with the fibres.  If this is a hard copy then the
C     viewport is the whole area.
C
      if (init) then
         if (hard) then
            call pgvstand
         else
            call pgvport(0.38*pscale(1),0.99,0.1,0.92)
         end if
         call pgwnad(-pgrad,pgrad,-pgrad,pgrad)
C
C     Otherwise, reset the viewport and the window to the way they were 
C     in the calling routine
C
      else
         call pgvport(vlim(1),vlim(2),vlim(3),vlim(4))
         call pgwindow(plotlim(1),plotlim(2),plotlim(3),plotlim(4))
      end if
C
C     Draw and label the axes
C 
      call pgbox('BCNSTA',0.0,0,'BCNSTA',0.0,0)
      call pglabel('microns','microns','Autofib 2 Configuration')
      call pgmtext('t',1.0,0.5,0.5,label(:chr_len(label)))
C
C     Mark pivot and park circles
C 
      call pgsfs(2)
      call pgcirc(0.0,0.0,real(piv_r))
      call pgcirc(0.0,0.0,field_size)
C
C     Reset the fill style
C
      call pgsfs(1)
C
C     Exit
C
  500 continue
      end
