      subroutine ssort(m,n,array,element)
C+------------------------------------------------------------------------------
C
C     Name:   
C        ssort
C
C     Invocation:
C        call ssort(m,n,array,element)
C
C     Description:
C        Sort a 2d array into increasing value of a specific column
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        m:  Integer (>)
C           First dimension of the array
C        n:  Integer (>)
C           Second dimension of the array
C        array:  Real array (!)
C           The array to be sorted
C        element:  Integer (>)
C           The column of the array to be used as the sort key
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        implicit none, variable names > 6 characters
C
C     Logical i/o units used:
C        none
C
C     External routines called:
C        none
C 
C     Algorithm:
C        -- Basic shell sorting algorithm extended for 2d arrays.  See 
C           Press, et. al. Numerical Recipes, p 228.
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version, based on N.R. routine 'shell'
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Parameters
C
      integer m
      integer n
      real array(m,n)
      integer element
C
C     Local parameters
C
      real invln2
      parameter (invln2=1.442695)
      real small
      parameter (small=1.0e-5)
C
C     Local variables
C
      integer ns,nsubs,n2,ilim,i,j,k,l
      real temp   
C
C     Get the size of the subarrays
C
      nsubs = int(alog(real(n))*invln2 + small)
      n2 = n
C
C     Loop over the number of subarrays
C
      do 30 ns = 1,nsubs
C
C        Get subarray limits
C
         n2 = n2/2
         ilim = n - n2
C
C        Outer insertion loop
C
         do 20 j = 1,ilim
            i = j
C
C           Inner insertion loop
C
   5        continue
            l = i + n2
            if (array(element,l) .lt. array(element,i)) then
               do 10 k = 1,m
                  temp = array(k,i)
                  array(k,i) = array(k,l)
                  array(k,l) = temp
  10           continue
               i = i - n2
               if (i .ge. 1) go to 5
            end if
  20     continue
  30  continue
      end
