      real function sumweights(npivots,allocated,weight)
C+------------------------------------------------------------------------------
C
C     Name:   
C        sumweights
C
C     Invocation:
C        sum = sumweights(npivots,allocated,weight)
C
C     Description:
C        Sum up the weights of the program objects which have been allocated.
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        npivots:  Integer (>)
C           The total number of pivots
C        allocated:  Integer array (>)
C           The reference number of the object which has been allocated
C           to a particular fibre.
C        weight:  Real array (>)
C           The weight assigned to each object
C     
C     Returns: 
C        sum:  Real
C           The sum of the weights of all of the program+fiducial objects
C           which have been allocated. (Sky patches not included).
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, variable names > 6 characters
C
C     Logical i/o units used:
C        none
C
C     External routines called:
C        none
C 
C     Algorithm:
C        -- Loop through the pivots.  If the pivot has been allocated and
C           its not a sky patch or a cursor position, then add the weight of
C           the object to the running sum.
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Global parameters
C
      include 'AF2_PAR.INC'
C
C     Parameters
C
      integer npivots
      integer allocated(npivots)
      real weight(*)
C
C     Local variables
C
      integer i,oref
      real sum
C
C     Initialise the sum of weights
C
      sum = 0.0
C
C     Now loop through all of the pivots.  If it has been allocated and
C     it's with an object, (e.g. not a sky) then add it into the sum
C
      do 10 i = 1,npivots
         oref = allocated(i)
         if ((oref .gt. 0) .and. (oref .lt. alloc_sky))
     :      sum = sum + weight(oref)
  10  continue
C
C     Send back the sum
C
      sumweights = sum
      end
